@@ -66,7 +66,7 @@ class Freebox(IPlugin):
 						for i in range int(rs['idx_sec']):
 							if rs['idx'][i - rang] == '|':
 								rangs.append(rang)
-								log.msg(" rang  :  %s" % (rangs)
+								log.msg(" rang  :  %s" % (rangs))
 #>>> for rang in range(len(mot)):  # La variable rang parcourt les entiers de 0 au rang de la dernière lettre du mot.
 #...     if mot[rang] == 'i':
 #...         rangs.append(rang)    # Si la lettre du mot est 'i', on stocke le rang dans notre liste.
@@ -79,7 +79,7 @@ class Freebox(IPlugin):
 								log.msg("idx_sec  :  %s" % (int(rs['idx_sec'])))
 								log.msg("idx  :  %s" % (rs['idx']))
 								resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
-								log.msg("resp  :  %s" % (resp))
+							log.msg("resp  :  %s" % (resp))
 				else:
 					log.msg("*************  'idx_sec'] = 1 ****************")
 					resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
